<div align="center">

<a href="https://github.com/offici5l/MiUnlockTool/releases/latest">
  <img src="https://img.shields.io/badge/MiUnlockTool-%23FF6900?style=flat&logo=xiaomi&logoColor=white" alt="MiUnlockTool" width="200"/>
</a>

<br>

[![Version](https://img.shields.io/pypi/v/miunlock?label=Version&labelColor=black&color=brightgreen)](https://pypi.org/project/miunlock/)
[![Changelog](https://img.shields.io/badge/Changelog-blue?style=flat&logoColor=white)](CHANGELOG.md)

[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](./LICENSE)

---

**Developed to retrieve `encryptData(token)` for Xiaomi devices to unlock the bootloader.**

**Compatible with all platforms.**

</div>

---

## Installation

```sh
pip install miunlock
```

### Quick Install Android(Termux):

```sh
curl -sS https://raw.githubusercontent.com/offici5l/MiUnlockTool/main/.install | bash
```

## Usage
```sh
miunlock
```